@@ -302,7 +302,7 @@ void brand_new_empty_cart_map (void)
 
 int load_cart_map (void)
 {
-	unsigned char		small_cart [LOADUNIT];
+	unsigned char		small_cart [SIZE_1K];
 	cart_map_locator_s*	endian_locator = NULL;
 	int			offset;
 	
@@ -317,9 +317,9 @@ int load_cart_map (void)
 		print("Searching for locator...\n");
 	for (offset = 0; !endian_locator && offset < CART_SIZE_BYTES; offset += CART_ROM_BLOCK_SIZE)
 	{
-		if (cart_read_mem(small_cart, GBA_ROM + offset + CART_ROM_BLOCK_SIZE - LOADUNIT, LOADUNIT) == -1)
+		if (cart_read_mem(small_cart, GBA_ROM + offset + CART_ROM_BLOCK_SIZE - SIZE_1K, SIZE_1K) == -1)
 			return -1;
-		endian_locator = (cart_map_locator_s*)&small_cart[LOADUNIT - sizeof(cart_map_locator_s)];
+		endian_locator = (cart_map_locator_s*)&small_cart[SIZE_1K - sizeof(cart_map_locator_s)];
 		if (ntoh32(endian_locator->magic) == MAP_MAGIC)
 		{
 			cart_map_max_number = ntoh16(endian_locator->number_of_entries);
