@@ -148,11 +148,11 @@ void adjust_load_addresses (int* offset, int* size)
 	// adjust offset so that it's a multiple of block
 	// adjust size so that it's a multiple of block
 	*size += *offset;
-	*offset &= ~(LOADUNIT - 1);
+	*offset &= ~(SIZE_1K - 1);
 	*size -= *offset;
-	if (*size & (LOADUNIT - 1))
-		*size += LOADUNIT;
-	*size &= ~(LOADUNIT - 1);
+	if (*size & (SIZE_1K - 1))
+		*size += SIZE_1K;
+	*size &= ~(SIZE_1K - 1);
 }
 
 void adjust_write_size (int* size)
@@ -191,11 +191,15 @@ int trim (const unsigned char* rom, int size)
 // subproject buildscripts, file tools/gba/gbafix.c
 typedef struct
 {
-	u_int32_t	start_code;			// B instruction
+	unsigned char	start_code1;			// B instruction
+	unsigned char	start_code2;			// B instruction
+	unsigned char	start_code3;			// B instruction
+	unsigned char	start_code4;			// B instruction
 	unsigned char	logo[0xA0-0x04];		// logo data
 	char		title[0xC];			// game title name
 	unsigned long	game_code;			//
-	u_int16_t	maker_code;			//
+	unsigned char	maker_code1;			//
+	unsigned char	maker_code2;			//
 	unsigned char	fixed;				// 0x96
 	unsigned char	unit_code;			// 0x00
 	unsigned char	device_type;			// 0x80
@@ -210,7 +214,7 @@ typedef struct
 static const rom_header_s good_header =
 {
 	// start_code
-	0xEA00002E,
+	0x2e, 0x00, 0x00, 0xea,
 	// logo
 	{ 0x24,0xFF,0xAE,0x51,0x69,0x9A,0xA2,0x21,0x3D,0x84,0x82,0x0A,0x84,0xE4,0x09,0xAD,
 	0x11,0x24,0x8B,0x98,0xC0,0x81,0x7F,0x21,0xA3,0x52,0xBE,0x19,0x93,0x09,0xCE,0x20,
@@ -227,7 +231,7 @@ static const rom_header_s good_header =
 	// game code
 	0x00000000,
 	// maker code
-	0x3130,
+	0x30, 0x31,
 	// fixed
 	0x96,
 	// unit_code
@@ -276,6 +280,9 @@ void correct_header (unsigned char* rom, const char* name, int force_name)
 	// this code seems to be now working.
 	// it might be cleaner if accurately using the rom_header_s structure.
 	
+	if (cart_verbose > 1)
+		print("(Updating header)\n");
+
 	char romname[13];
 	char romcode[5];
 	const char* shortname;
@@ -358,7 +365,7 @@ const char* filename2romname (const char* filename)
 int display_scanned_cart_map (void)
 {
 	int i;
-	unsigned char rom[LOADUNIT];
+	unsigned char rom[SIZE_1K];
 	
 	if (cart_io_sim > 1)
 	return 0;
@@ -366,7 +373,7 @@ int display_scanned_cart_map (void)
 	for (i = GBA_ROM; i < GBA_ROM + CART_SIZE_BYTES; i += CART_ROM_BLOCK_SIZE)
 	{
 		print("Trying address 0x%x...\r", i);
-		if (cart_read_mem(rom, i, LOADUNIT) == -1)
+		if (cart_read_mem(rom, i, SIZE_1K) == -1)
 			return -1;
 		if (has_good_header_for_reading(rom) > -1)
 		{
@@ -388,14 +395,14 @@ void auto_readandsave_rom (int numfiles, char* files[])
 	char autoname[64];
 	unsigned char rom[CART_ROM_BLOCK_SIZE];
 	
-	assert(CART_ROM_BLOCK_SIZE >= LOADUNIT);
+	assert(CART_ROM_BLOCK_SIZE >= SIZE_1K);
 	
 	if (cart_io_sim > 1)
 		return;
 
 	indexfile = 0;
 	i = GBA_ROM;
-	if (cart_read_mem(rom, i, LOADUNIT) < 0)
+	if (cart_read_mem(rom, i, SIZE_1K) < 0)
 		return;
 	do
 	{
@@ -460,7 +467,7 @@ void auto_readandsave_rom (int numfiles, char* files[])
 		
 		if (!nextblockloaded) // continue to look for ROM/valid header
 		{
-			if ((i += CART_ROM_BLOCK_SIZE) < GBA_ROM + CART_SIZE_BYTES && cart_read_mem(rom, i, LOADUNIT) < 0)
+			if ((i += CART_ROM_BLOCK_SIZE) < GBA_ROM + CART_SIZE_BYTES && cart_read_mem(rom, i, SIZE_1K) < 0)
 				return;
 		}
 	} while (i < GBA_ROM + CART_SIZE_BYTES);
@@ -486,18 +493,18 @@ void display_memory_map (const unsigned char* rom, int size)
 int is_same (int offset, int size, const unsigned char* mem)
 {
     int ret, i;
-    unsigned char rom [LOADUNIT];
+    unsigned char rom [SIZE_1K];
 	
     if (cart_io_sim > 1)
 	return -1;
 
-    for (i = offset; i < offset + size; i += LOADUNIT)
+    for (i = offset; i < offset + size; i += SIZE_1K)
     {
         // check beginning
-        cart_read_mem(rom, GBA_ROM + i, LOADUNIT);
-        ret = memcmp(rom, &mem[i], LOADUNIT);
+        cart_read_mem(rom, GBA_ROM + i, SIZE_1K);
+        ret = memcmp(rom, &mem[i], SIZE_1K);
         if (cart_verbose > 1 && ret != 0)
-            print("(offset 0x%x-0x%x BAD)\n", i, i + LOADUNIT - 1);
+            print("(offset 0x%x-0x%x BAD)\n", i, i + SIZE_1K - 1);
         if (ret != 0)
             return -1;
     }
@@ -516,12 +523,12 @@ int has_same_data (int offset, int size, const unsigned char* mem)
 	else
 	{
 		// check beginnning
-		if (is_same(offset, LOADUNIT, mem) == -1)
+		if (is_same(offset, SIZE_1K, mem) == -1)
 			return -1;
 
 		// roughly check end
-		size &= ~(LOADUNIT-1);
-		if (is_same(offset + size - LOADUNIT, LOADUNIT, mem) == -1)
+		size &= ~(SIZE_1K-1);
+		if (is_same(offset + size - SIZE_1K, SIZE_1K, mem) == -1)
 			return -1;
 	}
 	return 1;
@@ -678,7 +685,7 @@ int cart_file2sram (const char* file, int offset, int size)
 	
 	if ((sram = prepare_loadandwrite_sram(file, offset, size)) == NULL)
 		return -1;
-	ret = cart_direct_write(sram, GBA_SRAM, offset, size, size, offset, size);
+	ret = cart_direct_write(sram, GBA_SRAM, offset, size, SIZE_1K, offset, size);
 	print("\n");
 	free(sram);
 	return ret;
@@ -950,7 +957,7 @@ int auto_loadandburn_rom (cart_type_e cart_type, int cart_use_loader, int clean_
 		content_desc desc;
 		print("Wiping out content descriptor. You will need to launch CIZ to regenerate it.\n");
 		memset((char*) &desc, 0x99, sizeof(desc));
-		cart_direct_write((unsigned char*) &desc, F2AU_CD_BASE, 0, SIZE_64K, CART_WRITE_BLOCK_SIZE, 0, SIZE_64K);
+		cart_direct_write((unsigned char*) &desc, F2AU_CD_BASE, 0, SIZE_64K, SIZE_1K, 0, SIZE_64K);
 		print("\n");
 	}
 	
