@@ -9,7 +9,8 @@
 #ifndef __CARTROM_H__
 #define __CARTROM_H__
 
-#define LOADUNIT		1024		// minimum read data size on cart
+#define ASCII(x)	_ASCII((unsigned char)(x))
+#define _ASCII(x)	(((x) >= 32 && isascii(x))? (x): '.')
 
 int		cart_crc32			(const unsigned char *str, int *crc32buf, int size);
 int		trim				(const unsigned char* rom, int size);
