@@ -229,9 +229,6 @@ int main(int argc, char *argv[])
 			case 'P':
 				cart_type = CART_TYPE_F2A_PRO;
 				break;
-			case 'T':
-				cart_type = CART_TYPE_F2A_TURBO;
-				break;
 			case 'U':
 				cart_type = CART_TYPE_F2A_ULTRA;
 				break;
@@ -337,6 +334,7 @@ int main(int argc, char *argv[])
 			break;
 
 		case 'm':
+			mode = MODE_MB_USER;
 			multiboot_user_file = optarg;
 			break;
 
@@ -603,6 +601,17 @@ int main(int argc, char *argv[])
 		cart_exit(1);
 	}
 
+	// Send multiboot
+	if (mode == MODE_MB_USER)
+	{
+		if (cart_user_multiboot(multiboot_user_file) == -1)
+		{
+			printerr("Cannot send multiboot '%s' file to GBA.\n",
+				 multiboot_user_file);
+			cart_exit(1);
+		}
+	}
+
 	/* 
 	 * Now is the good moment to select a loader since we have a cart type. 
 	 *
@@ -668,17 +677,6 @@ int main(int argc, char *argv[])
 		cart_exit(1);
 	}
 
-	// Send multiboot
-	if (mode == MODE_MB_USER)
-	{
-		if (cart_user_multiboot(multiboot_user_file) == -1)
-		{
-			printerr("Cannot send multiboot '%s' file to GBA.\n",
-				 multiboot_user_file);
-			cart_exit(1);
-		}
-	}
-
 	// Show cart map : scanning method
 	if (mode == MODE_SCANNED_MAP)
 	{
@@ -897,5 +895,3 @@ int main(int argc, char *argv[])
 
 	return 0;		// make compiler happy
 }
-
-/* ex: set tabstop=8 expandtab: */
